pro scnd_ordr_test,ww=ww,wo=wo,filt,res,second,nosecond,ind=ind,$
	debug=debug

;+
;  NAME:  scnd_ordr_test
;
;  PURPOSE:	Compare time series of intensity in a sector around an
;		SSC image extending from 1.1 to 1.4 Rsun and 170 to 220
;		degrees (CW) in azimuth from SSCs with and without
;		second order leak correction.
;
;  CALLING EXAMPLE:
;	scnd_ordr_test,ww=ww,wo=wo,filt,res,second,nosecond, $
;		ind=ind,debug=debug
;	scnd_ordr_test,ww='ssc19990309_2131_001011.1', $
;		wo='ssc19990309_2131_001010.1',3,1, $
;		second,nosecond
;
;  INPUT:
;	filt, filter B number (Al.1=2, AlMg=3)
;	res, resolution (HR=1, QR=2)
;
;  KEYWORD INPUT:
;	ww, filename of SSC file with second order leak correction.
;	wo, filename of SSC file without second order correction.
;
;  OPTIONAL KEYWORD INPUT:
;	/debug stops the program at the end for checking parameters.
;
;  OUTPUT:
;	Plot to screen.
;
;  OPTIONAL OUTPUT
;	second, intensity time sequence of annuli with correction.
;	nosecond, intensity time sequence of annuli without correction.
;
;  OPTIONAL KEYWORD OUTPUT
;	ind, index structure of data arrays
;
;  HISTORY:
;	27-Jan-00 LWA, written.
;	28-Jan-00 LWA, changed shape of sampled area to increase
;		sensitivity of comparison.
;-

;  PROCESS THE "WITH" DATA

rd_roadmap,ww,rm
ii=where(gt_filtb(rm) eq filt and gt_res(rm) eq res)
if ii[0] LT 0 then begin
   message,/info,'No matches for filter/resolution requested'
   delvarx,second,nosecond
   return
endif
rd_sda,ww,ii,index,datw
ctr=sxt_cen(index)
case 1 of 
   res eq 1: ctr=shift_res(ctr,/xy,/fh)
   res eq 2: ctr=shift_res(ctr,/xy,/fq)
endcase
rad=get_rb0p(index,/radius)/gt_pix_size(index)  ; Solar radius in pixels.


;  COMPUTE THE ANNULUS AND SUM THE DATA

case 1 of
   res eq 1: nx=512
   res eq 2: nx=256
endcase

ll=n_elements(index)
second=fltarr(ll)
for i=0,ll-1 do begin
   pp=blank_circle(nx,nx,ctr(0,i),ctr(1,i),1.1*rad(i),1.4*rad(i))
   ann=bytarr(nx,nx)+1
   ann(pp)=0
   ann=ann eq 0
   ss=sector_bound(220,170,ctr(0,i),ctr(1,i),nx,nx)
   sect=bytarr(nx,nx)
   sect(ss)=1
   img=datw(0:nx-1,0:nx-1,i)
   second(i)=total(img*ann*sect)
endfor

;  GET THE "WITHOUT" DATA

rd_roadmap,wo,rmwo
jj=where(gt_filtb(rmwo) eq filt and gt_res(rmwo) eq res)
rd_sda,wo,jj,indwo,datwo
ctrwo=sxt_cen(indwo)
case 1 of
   res eq 1: ctrwo=shift_res(ctrwo,/xy,/fh)
   res eq 2: ctrwo=shift_res(ctrwo,/xy,/fq)
endcase
radwo=get_rb0p(indwo,/radius)/gt_pix_size(indwo)  ; Solar radius in pixels.

;  COMPUTE THE ANNULUS AND SUM THE DATA

kk=n_elements(indwo)
nosecond=fltarr(kk)
for i=0,kk-1 do begin
   pp=blank_circle(nx,nx,ctrwo(0,i),ctrwo(1,i),1.1*radwo(i),1.4*radwo(i))
   ann=bytarr(nx,nx)+1
   ann(pp)=0
   ann=ann eq 0
   ss=sector_bound(220,170,ctrwo(0,i),ctrwo(1,i),nx,nx)
   sect=bytarr(nx,nx)
   sect(ss)=1
   imgwo=datwo(0:nx-1,0:nx-1,i)
   nosecond(i)=total(imgwo*ann*sect)
endfor

;  PLOT THE RESULT

maxy = max([max(nosecond),max(second)])
utplot,psym=1,indwo,nosecond,yrange=[0.,maxy], $
   tit='Crosses=without, Solid=with 2nd order corr.'
outplot,index,second
xyouts,/norm,.2,.9,gt_filtb(index(0),/string)+'  '+$
   gt_res(index(0),/string),charsize=1.5

ind=index

if keyword_set(debug) then stop

end

