
;+

pro sxt_test_second, filesww, fileswo, filt=filt, res=res, cww=cww, cwo=cwo

;NAME:
;     sxt_test_second
;PURPOSE:
;     Test the second order leak correction
;CATEGORY:
;CALLING SEQUENCE:
;INPUTS:
;     filesww = A list of ssc files WITH the second order leak correction,
;               e.g. file_list('/net/dynamo/ypop/ssc/1995/')
;     fileswo = A list of ssc files WITHOUT the second order leak correction,
;               e.g. file_list('/net/dynamo/ypop/ssc_no2nd/1995/')
;OPTIONAL INPUT PARAMETERS:
;KEYWORD PARAMETERS
;     filt = filter number, Al.1=2, AlMg=3 (required)
;     res = resolution, HR=1, QR=2         (required)
;     cww = correlation of ww with ww/wo  (OUTPUT)
;     cwo = correlation of wo with ww/wo  (OUTPUT)
;OUTPUTS:
;     see cww and cwo above
;COMMON BLOCKS:
;SIDE EFFECTS:
;RESTRICTIONS:
;PROCEDURE:
;     If the variations in intensity in the suspect quadrent are due to a poor 
;     leak image, then ww will be smoother than wo.  So the correlation of ww
;     with ww/wo should be less than the correlation of wo with ww/wo in
;     magnitude (ignoring the sign of the correlation coefficient.
;
;     So, the output is the correlation coefficient of ww with ww/wo and the
;     coefficient of wo with ww/wo.  The output is an array with one number
;     for each input file.  Since the ssc files are one per day, the
;     correlation is done on a day by day basis.  This is about right to avoid 
;     solar changes, but still have enough images to check the correlation
;     vs. time.
;
;     The second test is the correlation of the intensity with pointing.  If
;     the leak is causing the variation then the variation should correalte
;     with pointing.  If the second order correction is successful, the the
;     correlation with pointing should be reduced when the second order leak
;     correction is applied.
;MODIFICATION HISTORY:
;     T. Metcalf 2000-Feb-07
;-

wwfilename = filesww
for j=0,n_elements(filesww)-1 do $
   wwfilename[j] = strmid((rotate(splitstr(filesww[j],'/'),2))[0],0,16)
wofilename = fileswo
for j=0,n_elements(fileswo)-1 do $
   wofilename[j] = strmid((rotate(splitstr(fileswo[j],'/'),2))[0],0,16)

delvarx,cwo,cww,index,bigsecond,bignosecond

for i=0,n_elements(filesww)-1 do begin

   sswofile = where(wofilename EQ wwfilename[i],nss)
   if sswofile[0] GE 0 then begin
      wwfile = filesww[i]
      wofile = fileswo[sswofile]

      print
      print,wwfile,' ',wofile
      print

      scnd_ordr_test,filt,res,second,nosecond,ww=wwfile,wo=wofile, $
         ind=ind,debug=0

      if n_elements(second) GT 0 and n_elements(nosecond) GT 0 then begin
         if n_elements(cwo) LE 0 then begin
            cwo = correlate(nosecond,second/nosecond)
            cww = correlate(second,second/nosecond)
            index = ind
            bigsecond = second
            bignosecond = nosecond
            xy = sxt_cen(ind)
            d = reform(sqrt((xy[0,*]-xy[0,0])^2+(xy[1,*]-xy[1,0])^2))
            bigd = d
            bigxy = xy
            cwod = correlate(nosecond,d)
            cwwd = correlate(second,d)
         endif else begin
            cwo = [cwo,correlate(nosecond,second/nosecond)]
            cww = [cww,correlate(second,second/nosecond)]
            index = [index,ind]
            bigsecond = [bigsecond,second]
            bignosecond = [bignosecond,nosecond]
            xy = sxt_cen(ind)
            d = reform(sqrt((xy[0,*]-xy[0,0])^2+(xy[1,*]-xy[1,0])^2))
            bigxy = [[bigxy],[xy]]
            bigd = [bigd,d]
            cwod = [cwod,correlate(nosecond,d)]
            cwwd = [cwod,correlate(second,d)]
         endelse
         print, 'Check that correlations without second are larger than correlations with second'
         print
         print,'correlate(second,second/nosecond): ', $
            correlate(second,second/nosecond)
         print,'correalte(second,pointing change):', $
            correlate(second,d)
         print,'correlate(nosecond,second/nosecond): ', $
            correlate(nosecond,second/nosecond)
         print,'correalte(nosecond,pointing change):', $
            correlate(nosecond,d)
      endif
   endif

endfor

maxy = max([max(cww),max(cwo)])
miny = min([min(cww),min(cwo)])
utplot,index,cww,yrange=[miny,maxy],psym=1  ; crosses
outplot,index,cwo,psym=2                    ; stars

maxy = max([max(abs(cww)),max(abs(cwo))])
miny = min([min(abs(cww)),min(abs(cwo))])
utplot,index,abs(cww),yrange=[miny,maxy],psym=1  ; crosses
outplot,index,abs(cwo),psym=2                    ; stars

psave = !p.multi
!p.multi = [0,1,2,0]
hist,(cwo),bin=.15,title='Correlation of Ratio Without Second Order Correction'
hist,(cww),bin=.15,title='Correlation of Ratio With Second Order Correction'
!p.multi = psave

; Print a report

print
print
print,'CORRELATION WITH WW/WO'
print
print,'Correlation on a file by file (i.e. day by day) basis:'
print
print,'With second order correction: ',mean((cww)),' +\- ',stddev((cww))
print,'Without second order correction: ',mean((cwo)),' +\- ',stddev((cwo))
print
print
print,'Correlation with ALL files included:'
print
print,'Total correlation with: ',correlate(bigsecond,bigsecond/bignosecond)
print,'Total correlation without: ',correlate(bignosecond,bigsecond/bignosecond)
print
print,'CORRELATION WITH POINTING'
print
print,'Correlation on a file by file (i.e. day by day) basis:'
print
print,'With second order correction: ',mean((cwwd)),' +\- ',stddev((cwwd))
print,'Without second order correction: ',mean((cwod)),' +\- ',stddev((cwod))
print
print
print,'Correlation with ALL files included:'
print
print,'Total correlation with: ',correlate(bigsecond,bigd)
print,'Total correlation without: ',correlate(bignosecond,bigd)
print

end
